function [f, g] = fdist_multiple_poly(lambda,pars)
% Emre Mengi (Modified on August 19, 2011)
%
% call: function [f, g] = fdist_defective(lambda,pars)
% task:
%		calculates 
%				f = sup_gamma 
%						sigma_(2n-1)([A - (lambda(1)+i*lambda(2))*I		gamma*I;
%													0		A - (lambda(1)+i*lambda(2))*I])
%		and its gradient g
% note:
%		the input matrix A must be passed through pars.A





[n,n2,m] = size(pars.P);
P = pars.P;

if (n ~= n2)
	error('P must be square');
end

%%%%%%%%%%%%%
% (1) First find optimal gamma
%%%%%%%%%%%%%
pars.lambda = lambda(1) + i*lambda(2);
pars.nvar = 2;
pars.fgname = 'dist_multiple_poly';


options.prtlevel = 0;
options.x0 = [1 -1]';
options.normtol = 10^-10;

[gamma,f] = bfgs(pars,options);


Pfun = pars.P(:,:,1);
for j = 1:m-1
	Pfun = Pfun + pars.lambda^j*P(:,:,j+1);
end


Pprime = pars.P(:,:,2);
for j = 2:m-1
	Pprime = Pprime + j*pars.lambda^(j-1)*pars.P(:,:,j+1);
end





% (2) Now evaluate the supremum function and
%	  its derivative at the optimal gamma


B = [Pfun   (gamma(1)+i*gamma(2))*Pprime;
	zeros(n)		Pfun];


[U,S,V] = svd(B);

S = diag(S);
[S,ind] = sort(S);

vm = V(:,ind(2));
vm = vm/norm(vm);
um = U(:,ind(2));
um = um/norm(um);


f = S(2);
g(1,1) = real(um(1:n)'*Pprime*vm(1:n)+um(n+1:2*n)'*Pprime*vm(n+1:2*n));
g(2,1) = -imag(um(1:n)'*Pprime*vm(1:n)+um(n+1:2*n)'*Pprime*vm(n+1:2*n));


return;