function [f, g] = fdist_multiple_poly(lambda,pars)
% Emre Mengi (Modified on August 19, 2011)
%
% call: function [f, g] = fdist_defective(lambda,pars)
% task:
%		calculates 
%				f = sup_gamma 
%						sigma_(2n-1)([A - (lambda(1)+i*lambda(2))*I		gamma*I;
%													0		A - (lambda(1)+i*lambda(2))*I])
%		and its gradient g
% note:
%		the input matrix A must be passed through pars.A





[n,n2,m] = size(pars.P);
P = pars.P;

if (n ~= n2)
	error('P must be square');
end

%%%%%%%%%%%%%
% (1) First find optimal gamma
%%%%%%%%%%%%%
pars.lambda = lambda(1) + i*lambda(2);
pars.nvar = 6;
pars.fgname = 'dist_triple_poly';


options.prtlevel = 0;
options.x0 = [1 1 1 -1 -1 -1]';
options.normtol = 10^-10;

[gamma,f] = bfgs(pars,options);


Pfun = pars.P(:,:,1);
for j = 1:m-1
	Pfun = Pfun + pars.lambda^j*P(:,:,j+1);
end


Pp = pars.P(:,:,2);
for j = 2:m-1
	Pp = Pp + j*pars.lambda^(j-1)*pars.P(:,:,j+1);
end

Ppp = 2*pars.P(:,:,3);
for j = 3:m-1
	Ppp = Ppp + j*(j-1)*pars.lambda^(j-2)*pars.P(:,:,j+1);
end





% (2) Now evaluate the supremum function and
%	  its derivative at the optimal gamma


Zn = zeros(n);

B = [	Pfun   (gamma(1)+i*gamma(4))*Pp		[(gamma(1)+i*gamma(4))*(gamma(3) + i*gamma(6))/2]*Ppp + (gamma(2)+i*gamma(5))*Pp;
		Zn		Pfun								(gamma(3) + i*gamma(6))*Pp;		
		Zn		Zn									Pfun							];

[U,S,V] = svd(B);

S = diag(S);
[S,ind] = sort(S);

vm = V(:,ind(3));
vm = vm/norm(vm);
um = U(:,ind(3));
um = um/norm(um);


f = S(3);
g(1,1) = real(um(1:n)'*Pp*vm(1:n)+um(n+1:2*n)'*Pp*vm(n+1:2*n)+um(2*n+1:3*n)'*Pp*vm(2*n+1:3*n));
g(2,1) = -imag(um(1:n)'*Pp*vm(1:n)+um(n+1:2*n)'*Pp*vm(n+1:2*n)+um(2*n+1:3*n)'*Pp*vm(2*n+1:3*n));


return;