function [f, g] = minimize_max_quad(omega,pars)
% Emre Mengi (Modified on July 23, 2013)
%
%
% to minimize the largest eigenvalue of
%  Q(omega) = C + sum_{j=1,d} omega_j L_j + sum_{j=1,d} sum_{k=j,d} omega_j omega_k Q_jk
%
% constant coefficient matrix: pars.C
% linear coefficient matrices: pars.L(:,:,j) j=1,...,d
% quadratic coefficient matrices: pars.Q(:,:,j,k) j,k=1,...,d
%	Note: pars.Q must be such that pars.Q(:,:,j,k) = pars.Q(:,:,k,j)
%
%

[m,n] = size(pars.C);
p = length(omega);

if (n ~= m)
	error('the input matrix must be square');
end


A = pars.C;
for j = 1:p
	A = A + omega(j,1)*pars.L(:,:,j);
end


for j = 1:p
	for k = j:p
		A = A + omega(j,1)*omega(k,1)*pars.Q(:,:,j,k);
	end
end


if (n <= 150)


	[V,D] = eig(A);

	f = D(n,n);


	for j = 1:p
		MA = pars.L(:,:,j) + 2*omega(j,1)*pars.Q(:,:,j,j);

		for k = 1:p
			if (k ~= j)
				MA = MA + omega(k,1)*pars.Q(:,:,j,k);
			end
		end

		g(j,1) = real(V(:,n)'*MA*V(:,n));
	end
else
			 
	[eigvec,d] = eigs(A,1,'lm');

	vm = eigvec(1:n,1);
	vm = vm/norm(vm);

	f = real(d(1,1));
	
	for j = 1:p
		MA = pars.L(:,:,j) + 2*omega(j,1)*pars.Q(:,:,j,j);
					  
		for k = 1:p
			if (k ~= j)
				MA = MA + omega(k,1)*pars.Q(:,:,j,k);
			end
		end
					  
		g(j,1) = real(vm'*MA*vm);
	end
end




return;